/poll "What would you like to see happen to Duchess get first?" "smarter: fewer wrong answers" "faster: more answers, less time" "flexible: scrape wikipedia when local answer not found" "teachable: upload documents like markdown docs, faqs, glossaries" "customizable: mix and match personalities/skills" "personal: user accounts"

## Court Jester:
    first merge request
    T-shirt

## Joan of Arc:
    purest code commit (high coverage & low flake)
    NLPIA eBook

## Knighthood:
    best new contribution in May
    Print book + T-shirt + lifetime subscription
